@@ -158,10 +158,7 @@ static const gchar *toggle_actions[] = {
   "next-def",
   "first-def",
   "last-def",
-  "select-all",
   "find",
-  "find-next",
-  "find-previous",
 };
 
 static gint n_toggle_state = G_N_ELEMENTS (toggle_actions);
@@ -893,40 +890,6 @@ gdict_window_cmd_file_print (GSimpleAction *action,
   			   GDICT_DEFBOX (window->defbox));
 }
 
-static void
-gdict_window_cmd_file_close_window (GSimpleAction *action,
-                                    GVariant      *parameter,
-                                    gpointer       user_data)
-{
-  GdictWindow *window = user_data;
-
-  g_assert (GDICT_IS_WINDOW (window));
-
-  gdict_window_store_state (window);
-
-  /* if this was called from the uimanager, destroy the widget;
-   * otherwise, if it was called from the delete_event, the widget
-   * will destroy itself.
-   */
-  if (action)
-    gtk_widget_destroy (GTK_WIDGET (window));
-}
-
-static void
-gdict_window_cmd_edit_select_all (GSimpleAction *action,
-                                  GVariant      *parameter,
-                                  gpointer       user_data)
-{
-  GdictWindow *window = user_data;
-
-  g_assert (GDICT_IS_WINDOW (window));
-
-  if (gtk_widget_has_focus (window->entry))
-    gtk_editable_select_region (GTK_EDITABLE (window->entry), 0, -1);
-  else
-    gdict_defbox_select_all (GDICT_DEFBOX (window->defbox));
-}
-
 static void
 gdict_window_cmd_edit_find (GSimpleAction *action,
                             GVariant      *parameter,
@@ -939,30 +902,6 @@ gdict_window_cmd_edit_find (GSimpleAction *action,
   gdict_defbox_set_show_find (GDICT_DEFBOX (window->defbox), TRUE);
 }
 
-static void
-gdict_window_cmd_edit_find_next (GSimpleAction *action,
-                                 GVariant      *parameter,
-                                 gpointer       user_data)
-{
-  GdictWindow *window = user_data;
-
-  g_assert (GDICT_IS_WINDOW (window));
-
-  gdict_defbox_find_next (GDICT_DEFBOX (window->defbox));
-}
-
-static void
-gdict_window_cmd_edit_find_previous (GSimpleAction *action,
-                                     GVariant      *parameter,
-                                     gpointer       user_data)
-{
-  GdictWindow *window = user_data;
-
-  g_assert (GDICT_IS_WINDOW (window));
-
-  gdict_defbox_find_previous (GDICT_DEFBOX (window->defbox));
-}
-
 static void
 gdict_window_cmd_change_view_sidebar (GSimpleAction *action,
                                       GVariant      *state,
@@ -1148,13 +1087,9 @@ static const GActionEntry entries[] =
   { "save-as", gdict_window_cmd_save_as, NULL, NULL, NULL },
   { "preview", gdict_window_cmd_file_preview, NULL, NULL, NULL },
   { "print", gdict_window_cmd_file_print, NULL, NULL, NULL },
-  { "close", gdict_window_cmd_file_close_window, NULL, NULL, NULL },
 
-  /* Edit menu */
-  { "select-all", gdict_window_cmd_edit_select_all, NULL, NULL, NULL },
+  /* Find item */
   { "find", gdict_window_cmd_edit_find, NULL, NULL, NULL },
-  { "find-next", gdict_window_cmd_edit_find_next, NULL, NULL, NULL },
-  { "find-previous", gdict_window_cmd_edit_find_previous, NULL, NULL, NULL },
 
   /* Go menu */
   { "previous-def", gdict_window_cmd_go_previous_def, NULL, NULL, NULL },
@@ -1180,7 +1115,11 @@ gdict_window_delete_event_cb (GtkWidget *widget,
 			      GdkEvent  *event,
 			      gpointer   user_data)
 {
-  gdict_window_cmd_file_close_window (NULL, NULL, GDICT_WINDOW (widget));
+  GdictWindow *window = GDICT_WINDOW (widget);
+
+  g_assert (GDICT_IS_WINDOW (window));
+
+  gdict_window_store_state (window);
 
   return FALSE;
 }
@@ -1344,21 +1283,6 @@ gdict_window_link_clicked (GdictDefbox *defbox,
   g_signal_emit (window, gdict_window_signals[CREATED], 0, new_window);
 }
 
-static void
-gdict_window_defbox_selection_changed (GdictDefbox *defbox,
-                                       GdictWindow *window)
-{
-  GAction *action;
-  gboolean has_selection;
-
-  action = g_action_map_lookup_action (G_ACTION_MAP (window), "copy");
-  if (action)
-    {
-      has_selection = gdict_defbox_get_has_selection (defbox);
-      g_simple_action_set_enabled (G_SIMPLE_ACTION (action), has_selection);
-    }
-}
-
 static void
 gdict_window_drag_data_received_cb (GtkWidget        *widget,
 				    GdkDragContext   *context,
@@ -1491,10 +1415,6 @@ gdict_window_constructor (GType                  type,
   g_signal_connect (window->defbox, "link-clicked",
                     G_CALLBACK (gdict_window_link_clicked),
                     window);
-  g_signal_connect (GDICT_DEFBOX (window->defbox), "selection-changed",
-                    G_CALLBACK (gdict_window_defbox_selection_changed),
-                    window);
-  gdict_window_defbox_selection_changed (GDICT_DEFBOX (window->defbox), window);
 
   gtk_drag_dest_set (window->defbox,
   		     GTK_DEST_DEFAULT_ALL,
